@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2016-01-07'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -869,7 +869,6 @@ $SPEC{format_result} = {
             schema => 'array*', # XXX envres
             req => 1,
             pos => 0,
-            cmdline_src => 'stdin_or_file',
         },
     },
     args_as => 'array',
@@ -1474,6 +1473,10 @@ sub bencher {
             for my $mod (@modules) {
                 $code_load->($mod);
             }
+            for my $mod (keys %{$parsed->{modules}}) {
+                next if $mod eq 'perl';
+                $code_load->($mod);
+            }
         }
 
         my $on_failure = $args{on_failure} // $parsed->{on_failure} // 'die';
@@ -1617,7 +1620,7 @@ sub bencher {
 
     }
 
-    $envres = [304,"No action"];
+    $envres = [400,"Unknown action"];
 
   L_END:
 
@@ -1665,7 +1668,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.23 of Bencher (from Perl distribution Bencher), released on 2016-01-06.
+This document describes version 0.24 of Bencher (from Perl distribution Bencher), released on 2016-01-07.
 
 =head1 SYNOPSIS
 
